@@ -3,7 +3,6 @@ import pathlib
 import time
 import os
 import json
-import re
 import shutil
 import subprocess
 import unittest
@@ -53,7 +52,6 @@ class TestCase(unittest.TestCase):
         except FileNotFoundError:
             'already removed'
 
-
     def build_and_publish(self):
         git_push()
         self.remove_dist()
@@ -125,34 +123,6 @@ def to_camel_case(text):
 def get_commit_message():
     return input("Enter commit message: ")
 
-def pyproject():
-    return 'pyproject.toml'
-
-def get_pyproject():
-    with open(pyproject()) as file:
-        return file.read()
-
-def semantic_version_pattern():
-    return r'version\s+=\s+"(\d+[.]\d+[.])(\d+)"'
-
-def get_pyproject_version(text):
-    return re.search(
-        semantic_version_pattern(),
-        text
-    ).group(1, 2)
-
-def update_pyproject_version():
-    text = get_pyproject()
-    version, patch = get_pyproject_version(text)
-    write_file(
-        filepath=pyproject(),
-        data=re.sub(
-            semantic_version_pattern(),
-            f'version = "{version}{int(patch)+1}"',
-            text
-        )
-    )
-
 def git_push():
     try:
         update_pyproject_version()
