@@ -1,12 +1,14 @@
+import src.jadecobra.toolkit
+import src.jadecobra.versioning
+import os
 import unittest
-import jadecobra.toolkit
 
 
-class TestJadeCobra(jadecobra.toolkit.TestCase):
+class TestJadeCobra(src.jadecobra.toolkit.TestCase):
 
     def test_toolkit_test_case_attributes(self):
         self.assert_attributes_equal(
-            jadecobra.toolkit.TestCase,
+            src.jadecobra.toolkit.TestCase,
             [
                 '__call__',
                 '__class__',
@@ -18,6 +20,7 @@ class TestJadeCobra(jadecobra.toolkit.TestCase):
                 '__format__',
                 '__ge__',
                 '__getattribute__',
+                '__getstate__',
                 '__gt__',
                 '__hash__',
                 '__init__',
@@ -36,7 +39,7 @@ class TestJadeCobra(jadecobra.toolkit.TestCase):
                 '__subclasshook__',
                 '__weakref__',
                 '_addExpectedFailure',
-                '_addSkip',
+                # '_addSkip',
                 '_addUnexpectedSuccess',
                 '_baseAssertEqual',
                 '_callCleanup',
@@ -47,7 +50,7 @@ class TestJadeCobra(jadecobra.toolkit.TestCase):
                 '_class_cleanups',
                 '_deprecate',
                 '_diffThreshold',
-                '_feedErrorsToResult',
+                # '_feedErrorsToResult',
                 '_formatMessage',
                 '_getAssertEqualityFunc',
                 '_truncateMessage',
@@ -105,6 +108,8 @@ class TestJadeCobra(jadecobra.toolkit.TestCase):
                 'defaultTestResult',
                 'doClassCleanups',
                 'doCleanups',
+                'enterClassContext',
+                'enterContext',
                 'fail',
                 'failIf',
                 'failIfAlmostEqual',
@@ -132,7 +137,7 @@ class TestJadeCobra(jadecobra.toolkit.TestCase):
 
     def test_toolkit(self):
         self.assert_attributes_equal(
-            jadecobra.toolkit,
+            src.jadecobra.toolkit,
             [
                 'TestCase',
                 '__builtins__',
@@ -149,8 +154,8 @@ class TestJadeCobra(jadecobra.toolkit.TestCase):
                 'error',
                 'file_exists',
                 'get_commit_message',
-                'get_pyproject',
-                'get_pyproject_version',
+                # 'get_pyproject',
+                # 'get_pyproject_version',
                 'git_push',
                 'header',
                 'json',
@@ -159,16 +164,16 @@ class TestJadeCobra(jadecobra.toolkit.TestCase):
                 'make_dir',
                 'os',
                 'pathlib',
-                'pyproject',
-                're',
-                'semantic_version_pattern',
+                # 'pyproject',
+                # 're',
+                # 'semantic_version_pattern',
                 'shutil',
                 'subprocess',
                 'time',
                 'time_it',
                 'to_camel_case',
                 'unittest',
-                'update_pyproject_version',
+                # 'update_pyproject_version',
                 'write_config',
                 'write_file'
             ]
@@ -176,14 +181,48 @@ class TestJadeCobra(jadecobra.toolkit.TestCase):
 
     def test_to_camel_case(self):
         self.assertEqual(
-            jadecobra.toolkit.to_camel_case('abc-def-hij'),
+            src.jadecobra.toolkit.to_camel_case('abc-def-hij'),
             'AbcDefHij'
         )
 
+    def test_versioning(self):
+        self.assert_attributes_equal(
+            src.jadecobra.versioning,
+            [
+                '__builtins__',
+                '__cached__',
+                '__doc__',
+                '__file__',
+                '__loader__',
+                '__name__',
+                '__package__',
+                '__spec__',
+                'get_pyproject',
+                'get_pyproject_version',
+                'git_push',
+                'os',
+                'pyproject',
+                're',
+                'semantic_version_pattern',
+                'toolkit',
+                'update_pyproject_version',
+                'update_version'
+            ]
+        )
+
     def test_update_version(self):
+        import src.jadecobra as test
         self.assertEqual(
-            jadecobra.toolkit.get_pyproject_version(
-                jadecobra.toolkit.get_pyproject()
+            src.jadecobra.versioning.get_pyproject_version(
+                src.jadecobra.versioning.get_pyproject()
             ),
-            ('0.2.', '4')
-        )
\ No newline at end of file
+            ('0.2.', '6'),
+        )
+
+    def test_published_version_is_test_version(self):
+        os.system('pip install jadecobra')
+        import jadecobra
+        self.assertEqual(
+            jadecobra.__version__,
+            src.jadecobra.__version__
+        )
